"""
This mod use the Django's `Sitemap framework`_ to publish the ``sitemap.xml`` for various apps. The default config contains ressources for DjangoCMS, Zinnia, staticpages, contact form and Porticus but only ressource for DjangoCMS is enabled.

Uncomment ressources or add new app ressources for your needs (see the Django documentation for more details).
"""


# -*- coding: utf-8 -*-
"""
Enable the customization of the `CKEditor`_ editor. It is enabled by default and used by `Django CKEditor`_ in the `cms`_ mod, and also in `zinnia`_.

Use "djangocms_text_ckeditor", a djangocms plugin to use CKEditor (4.x) instead of the default one

This mod contains some tricks to enable "django-filebrowser" usage with "image" plugin from CKEditor.

And some contained patches/fixes :

* the codemirror plugin that is not included in djangocms-text-ckeditor;
* Some missed images for the "showblocks" plugin;
* A system to use the "template" plugin (see views.EditorTemplatesListView for more usage details);
* Some patch/overwrites to have content preview and editor more near to Foundation;
"""


"""
Enable `Django registration`_ and everything you need to allow users to request registration and to connect/disconnect. The views and forms are added so this part can be used. 

It includes:

* A view for the login and one for the logout;
* All the views for the registration request (request, confirmation, etc.);
* A view to ask for the reinitialization of a password.

In the ``skeleton.html`` template, a partial HTML code is commented. Uncomment it to display the *logout* button when the user is connected.

The registration process consists in sending an email (to be configured in the settings) with the registration request to an administrator responsible for accepting them (or not). Once validated, an email is sent to the user to confirm his registration by way of a link. Once this step has been completed, the user can connect.
"""


"""
`Django CMS`_ allows for the creation and management of the content pages that constitute your site's tree structure. By default, this component enables the use of `filebrowser`_, `Django CKEditor`_ and `emencia-cms-snippet`_ (a clone of the snippets' plugin with a few improvements).

By default it is configured to use only one language. See its ``urls.py`` to find out how to enable the management of multiple languages.
"""



from django.contrib import admin
from django.utils.translation import ugettext_lazy as _

from .models import UserInfo

class UserInfoAdmin(admin.ModelAdmin):
    list_display = ('user', 'lastname', 'firstname', 'company', 'function',)
    raw_id_fields = ['user']
    search_fields = ('user__username', 'firstname', 'lastname', 'company',)

admin.site.register(UserInfo, UserInfoAdmin)



# -*- coding: utf-8 -*-
"""
Views to customize CKEditor

These views are for admin staff only, we don't want to expose them.
"""
import os, json

from django.conf import settings
from django.contrib.auth import REDIRECT_FIELD_NAME
from django.contrib.auth.views import redirect_to_login
from django.core.urlresolvers import reverse
from django.views.generic import View, TemplateView
from django.core.exceptions import PermissionDenied
from django.http import HttpResponse, Http404

class StaffuserRequiredMixin(object):
    """
    Mixin allows you to require a user with `is_staff` set to True.
        
    Taken from django-braces
    """
    login_url = settings.LOGIN_URL  # LOGIN_URL from project settings
    raise_exception = False  # Default whether to raise an exception to none
    redirect_field_name = REDIRECT_FIELD_NAME  # Set by django.contrib.auth

    def dispatch(self, request, *args, **kwargs):
        if not request.user.is_staff:  # If the request's user is not staff,
            if self.raise_exception:  # *and* if an exception was desired
                raise PermissionDenied  # return a forbidden response
            else:
                return redirect_to_login(request.get_full_path(),
                                         self.login_url,
                                         self.redirect_field_name)

        return super(StaffuserRequiredMixin, self).dispatch(request,
            *args, **kwargs)

class EditorTemplatesListView(StaffuserRequiredMixin, View):
    """
    Recursively list all HTML file in settings.CKEDITOR_EDITOR_TEMPLATES_PATH 
    that didn't start with "_" and return the list in a Javascript file :
    
        // Register a templates definition set named "default".
        CKEDITOR.addTemplates( 'default', {
            // The name of sub folder which hold the shortcut preview images of the
            // templates.
            imagesPath: '/static/ckeditor/editor-site-templates/',

            // The templates definitions.
            templates: [
                {
                    title: 'Grid row',
                    image: 'grid_row.gif',
                    description: 'Sample',
                    html: '<div class="row"></div>'
                }
            ]
        }
    
    The Django template loading behaviors should be preserved, so you can overrides them 
    within multiple TEMPLATE_DIRS. Prefix your file names with "_" for included 
    templates that you don't want to see in the editor templates list.
    
    On the root of the settings.CKEDITOR_EDITOR_TEMPLATES_PATH directory, 
    should resides a "manifest.json" file that contain a map to your content templates to 
    declare their optionnal title and description. When a content template has no 
    declared title it take his relative path as title, and the default description is 
    "No description".
    
    Your "manifest.json" file should look like :
    
        {
            "foo.html": {
                "title": "Dummy",
                "image": "grid_row.gif",
                "description": "Dummy template for testing"
            }
        }
        
    The template HTML is taken from the template filename given at the key name.
    
    Take care to make valid JSON, else this will raise exception. Also note that content 
    templates are indexed on their relative path.
    """
    def get(self, request, *args, **kwargs):
        imagespath = os.path.join(settings.STATIC_URL, settings.CKEDITOR_EDITOR_TEMPLATES_IMAGES_PATH)
        return HttpResponse(
                    settings.CKEDITOR_EDITOR_JS_TEMPLATE.format(imagespath=imagespath, json_list=json.dumps(self.get_templates(), indent=4)),
                    content_type="application/javascript"
                )
    
    def get_templates(self):
        manifest, paths = {}, []
        TPL_OBJ = {
            'title': 'Dummy title',
            'image': '',
            'description': '',
            'html': 'Empty'
        }
        
        # Perform scanning on all knowed templates directory
        for dir in settings.TEMPLATE_DIRS:
            templates_dir = os.path.join(dir, settings.CKEDITOR_EDITOR_TEMPLATES_PATH)
            if os.path.exists(templates_dir):
                # Trying to find the optional manifest JSON file that describes templates
                manifest_file = os.path.join(templates_dir, settings.CKEDITOR_EDITOR_TEMPLATES_NAMES_FILE)
                if os.path.exists(manifest_file):
                    manifest.update(json.load(open(manifest_file, 'r')))
                
                for root, dirs, files in os.walk(templates_dir):
                    
                    for name in files:
                        if not name.startswith('_') and name.endswith('.html'):
                            item_obj = TPL_OBJ.copy()
                            absolute = os.path.join(root, name)
                            relative = os.path.relpath(absolute, templates_dir)
                            # Default content
                            item_obj['title'] = name
                            # Get the HTML content
                            fp = open(absolute, "r")
                            item_obj['html'] = fp.read()
                            fp.close()
                            # If the entry is defined in the manifest
                            if relative in manifest:
                                item_obj['title'] = manifest[relative].get('title') or item_obj['title']
                                item_obj['description'] = manifest[relative].get('description') or item_obj['description']
                                item_obj['image'] = manifest[relative].get('image') or item_obj['image']
                                
                                paths.append(item_obj)
        
        return paths
        


"""
Enable a module in ``settings.TEMPLATE_CONTEXT_PROCESSORS`` to show a few variables linked to `Django sites app`_ in the context of the project views template.

Common context available variables are:

* ``SITE.name``: Current *Site* entry name;
* ``SITE.domain``: Current *Site* entry domain;
* ``SITE.web_url``: The Current *Site* entry domain prefixed with the http protocol like ``http://mydomain.com``. If HTTPS is enabled 'https' will be used instead of 'http';

Some projects can change this to add some other variables, you can see for them in ``project.utils.context_processors.get_site_metas``.
"""


from django.conf import settings
from django.contrib.sites.models import RequestSite
from django.contrib.sites.models import Site

from django.contrib.auth.views import login as login_base
from django.contrib.auth.views import password_change as password_change_base
from django.contrib.auth.views import password_reset as password_reset_base
from django.contrib.auth.views import password_reset_confirm as password_reset_confirm_base

from registration.backends.default.views import RegistrationView as RegisView
from registration.backends.default.views import ActivationView as ActView
from registration.models import RegistrationProfile
from registration import signals

from .models import UserInfo
from .forms import AuthenticationFormAccounts, PasswordChangeFormAccounts, PasswordResetFormAccounts, SetPasswordFormAccounts, RegistrationFormAccounts

from .email_sender import send_activation_email, send_activation_pending_email, send_confirmation_email

def login(*args, **kwargs):
    """
    Override view to use a custom Form
    """
    kwargs['authentication_form'] = AuthenticationFormAccounts
    return login_base(*args, **kwargs)

def password_change(*args, **kwargs):
    """
    Override view to use a custom Form
    """
    kwargs['password_change_form'] = PasswordChangeFormAccounts
    return password_change_base(*args, **kwargs)

def password_reset(*args, **kwargs):
    """
    Override view to use a custom Form
    """
    kwargs['password_reset_form'] = PasswordResetFormAccounts
    return password_reset_base(*args, **kwargs)

def password_reset_confirm(*args, **kwargs):
    """
    Override view to use a custom Form
    """
    kwargs['set_password_form'] = SetPasswordFormAccounts
    return password_reset_confirm_base(*args, **kwargs)



class RegistrationView(RegisView):
    """
    Overload on Registration class
    """
    form_class = RegistrationFormAccounts

    def register(self, request, **cleaned_data):
        """
        Given a username, email address and password, register a new
        user account, which will initially be inactive.

        Along with the new ``User`` object, a new
        ``registration.models.RegistrationProfile`` will be created,
        tied to that ``User``, containing the activation key which
        will be used for this account.

        Two emails will be sent. First one to the admin; this email should
        contain an activation link and a resume of the new user infos.
        Second one, to the user, for inform him that his request is pending.

        After the ``User`` and ``RegistrationProfile`` are created and
        the activation email is sent, the signal
        ``registration.signals.user_registered`` will be sent, with
        the new ``User`` as the keyword argument ``user`` and the
        class of this backend as the sender.

        """
        username = cleaned_data['username']
        email = cleaned_data['email']
        password = cleaned_data['password1']
        lastname = cleaned_data['lastname']
        firstname = cleaned_data['firstname']
        company = cleaned_data['company']
        function = cleaned_data['function']
        if Site._meta.installed:
            site = Site.objects.get_current()
        else:
            site = RequestSite(request)
        create_user = RegistrationProfile.objects.create_inactive_user
        new_user = create_user(username, email, password, site,
                               send_email=False)
        new_user.first_name = firstname
        new_user.last_name = lastname
        new_user.save()
        user_info = UserInfo(lastname=lastname, company=company,
                             function=function)
        user_info.user = new_user
        user_info.firstname = firstname
        user_info.address = cleaned_data['address']
        user_info.postal_code = cleaned_data['postal_code']
        user_info.city = cleaned_data['city']
        user_info.country = cleaned_data['country']
        user_info.phone = cleaned_data['phone']
        user_info.save()
        send_activation_email(new_user, site, user_info)
        send_activation_pending_email(new_user, site, user_info)
        signals.user_registered.send(sender=self.__class__,
                                     user=new_user,
                                     request=request)
        return new_user


class ActivationView(ActView):
    def activate(self, request, activation_key):
        user = super(ActivationView, self).activate(request, activation_key)
        if Site._meta.installed:
            site = Site.objects.get_current()
        else:
            site = RequestSite(request)
        if user:
            send_confirmation_email(user, site)
        return user



"""
Settings to enable the django-debug-toolbar
"""
# Must match the IP adress you will use to access to the instance
INTERNAL_IPS = ()

DEBUG_TOOLBAR_PATCH_SETTINGS = False

# Options 
DEBUG_TOOLBAR_CONFIG = {
    'INTERCEPT_REDIRECTS': False,
}
DEBUG_TOOLBAR_PANELS = (
    #'debug_toolbar.panels.versions.VersionsPanel',
    #'debug_toolbar.panels.timer.TimerPanel',
    'debug_toolbar.panels.settings.SettingsPanel',
    'debug_toolbar.panels.headers.HeadersPanel',
    'debug_toolbar.panels.request.RequestPanel',
    #'debug_toolbar.panels.sql.SQLPanel',
    'debug_toolbar.panels.staticfiles.StaticFilesPanel',
    'debug_toolbar.panels.templates.TemplatesPanel',
    #'debug_toolbar.panels.cache.CachePanel',
    #'debug_toolbar.panels.signals.SignalsPanel',
    #'debug_toolbar.panels.logging.LoggingPanel',
    #'debug_toolbar.panels.redirects.RedirectsPanel',
)

# Registering the debug_toolbar app and middleware
MIDDLEWARE_CLASSES = ('debug_toolbar.middleware.DebugToolbarMiddleware',) \
                     + MIDDLEWARE_CLASSES

INSTALLED_APPS = add_to_tuple(INSTALLED_APPS, 'debug_toolbar')



from django.contrib.auth.models import User
from django.db import models
from django.utils.translation import ugettext_lazy as _

class UserInfo(models.Model):

    user = models.ForeignKey(User, unique=True, verbose_name=_('user'))

    firstname = models.CharField(_('Firstname'), max_length=100, blank=True)
    lastname = models.CharField(_('Lastname'), max_length=100)
    company = models.CharField(_('Company'), max_length=100)
    function = models.CharField(_('Function'), max_length=256)
    address = models.TextField(_('Address'), blank=True)
    postal_code = models.CharField(_('Postal code'), max_length=15, blank=True)
    city = models.CharField(_('City'), max_length=100, blank=True)
    country = models.CharField(_('Country'), max_length=100, blank=True)
    phone = models.CharField(_('Professional phone number'), max_length=25,
                             blank=True)



# -*- coding: utf-8 -*-
"""
Menu stuff for admin_tools
"""
from django.conf import settings
from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _

from admin_tools.menu import items, Menu

class LanguageMenuItem(items.MenuItem):
    """
    Dummy custom MenuItem to use the template with the language chooser form
    """
    title = _('Language')
    template = 'admin/admintool_language_chooser.html'
        
class CustomMenu(Menu):
    """
    Custom Menu for project admin site.
    """
    def __init__(self, **kwargs):
        Menu.__init__(self, **kwargs)
        self.children += [
            items.MenuItem(_('Dashboard'), reverse('admin:index')),
            items.Bookmarks(),
            items.AppList(
                _('Applications'),
                exclude=('django.contrib.*',)
            ),
            items.AppList(
                _('Administration'),
                models=('django.contrib.*',)
            ),
            items.MenuItem(_('Filebrowser'), reverse('fb_browse')),
            #LanguageMenuItem(),
        ]

    def init_with_context(self, context):
        """
        Use this method if you need to access the request context.
        """
        return super(CustomMenu, self).init_with_context(context)



"""
`Django Blog Zinnia`_ allows for the management of a blog in your project. It is perfectly integrated into the `cms`_ component but can also be used independently.

At the time of installation, an automatic patch (that can be viewed in the ``patches/`` directory) is applied to it to implement the use of `ckeditor`_, which is enabled by default in its settings.
"""


from django.conf import settings
from django.template.loader import render_to_string
from django.core.mail import send_mail

def send_activation_email(user, site, user_info):

    activate_user = user.registrationprofile_set.all()[0]
    ctx_dict = {'activation_key': activate_user.activation_key,
                'expiration_days': settings.ACCOUNT_ACTIVATION_DAYS,
                'username': user.username,
                'email': user.email,
                'user_info': user_info,
                'site': site}
    subject = render_to_string('registration/activation_email_subject.txt',
                               ctx_dict)
    # Email subject *must not* contain newlines
    subject = ''.join(subject.splitlines())

    message = render_to_string('registration/activation_email.txt',
                               ctx_dict)
    send_mail(subject, message, settings.DEFAULT_FROM_EMAIL,
              settings.DEFAULT_ACTIVE_SUBSCRIBE_EMAILS)

def send_activation_pending_email(user, site, user_info):

    ctx_dict = {'site': site,
                'username': user.username,
                'email': user.email,
                'user_info': user_info}
    subject = render_to_string('registration/activation_pending_email_subject.txt',
                               ctx_dict)
    # Email subject *must not* contain newlines
    subject = ''.join(subject.splitlines())

    message = render_to_string('registration/activation_pending_email.txt',
                               ctx_dict)
    user.email_user(subject, message, settings.DEFAULT_FROM_EMAIL)

def send_confirmation_email(user, site):

    ctx_dict = {'site': site}
    subject = render_to_string('registration/confirmation_email_subject.txt',
                               ctx_dict)
    # Email subject *must not* contain newlines
    subject = ''.join(subject.splitlines())

    message = render_to_string('registration/confirmation_email.txt',
                               ctx_dict)
    user.email_user(subject, message, settings.DEFAULT_FROM_EMAIL)



# -*- coding: utf-8 -*-
"""
Settings to enable admin_tools
"""
ADMIN_TOOLS_MENU = "project.mods_enabled.admin_tools.menu.CustomMenu"
ADMIN_TOOLS_INDEX_DASHBOARD = "project.mods_enabled.admin_tools.dashboard.CustomIndexDashboard"
ADMIN_TOOLS_APP_INDEX_DASHBOARD = "project.mods_enabled.admin_tools.dashboard.CustomAppIndexDashboard"

INSTALLED_APPS = add_to_tuple(INSTALLED_APPS,
    'admin_tools',
    'admin_tools.theming',
    'admin_tools.menu',
    'admin_tools.dashboard',
    before='django.contrib.admin')

TEMPLATE_CONTEXT_PROCESSORS = add_to_tuple(TEMPLATE_CONTEXT_PROCESSORS,
    'django.core.context_processors.request',
)



"""
Add `Django Filebrowser`_ to your project so you can use a centralized interface to manage the uploaded files to be used with other components (`cms`_, `zinnia`_, etc.).

The version used is a special version called *no grappelli* that can be used outside of the *django-grapelli* environment.
"""


"""
Enable `django-assets`_ to combine and minify your *assets* (CSS, JS). The minification library used, *yuicompressor*, requires the installation of Java (the OpenJDK installed by default on most Linux systems is sufficient).

In general, this component is required. If you do not intend to use it, you will need to modify the project's default templates to remove all of its occurrences.
"""



"""
Add `django-debug-toolbar`_ to your project to insert a tab on all of your project's HTML pages, which will allow you to track the information on each page, such as the template generation path, the  query arguments received, the number of SQL queries submitted, etc.

This component can only be used in a development or integration environment and is always disabled during production.

Note that its use extends the response time of your pages and can provokes some mysterious bugs (like with syncdb or zinnia) so for the time being, this mods is disabled. So enable it locally for your needs, but never commit its enabled mod and remember to disable it when you have a strange bug.
"""


"""
A simple contact form that is more of a standard template than a full-blown application. You can modify it according to your requirements in its ``apps/contact_form/`` directory. Its HTML rendering is managed by `crispy_forms`_ based on a customized layout.

By default, it uses the `recaptcha`_ mods.
"""


# -*- coding: utf-8 -*-
"""
Views for contact forms
"""
from django.core.urlresolvers import reverse
from django.views.generic.edit import FormView

from .forms import ContactForm

class ContactFormBaseView(FormView):
    """
    Base view for contact forms
    """
    template_name = 'contact_form/contact_form.html'
    form_class = ContactForm
    
    def get_success_url(self):
        return reverse('contact_form_sent')

    def form_valid(self, form):
        form.save()
        return super(ContactFormBaseView, self).form_valid(form)


class ContactFormView(ContactFormBaseView):
    """Contact form view"""
    form_class = ContactForm



"""
Enable `django-admin-tools`_ to enhance the administration interface. This enables three widgets to customize certain elements. `filebrowser`_ is used, so if your project has not enabled it, you need to remove the occurrences of these widgets.
"""



"""
Add `Django PDB`_ to your project for more precise debugging with breakpoints. 

N.B. Neither ``django_pdb`` nor ``pdb`` are installed by the buildout. You must install 
them manually, for example with `pip`_, in your development environment so you do not 
disrupt the installation of projects being integrated or in production. You must also 
add the required breakpoints yourself.

See the the django-pdb Readme for more usage details.

.. note::
        django-pdb should be put at the end of settings.INSTALLED_APPS :
        
        "Make sure to put django_pdb after any conflicting apps in INSTALLED_APPS so 
        that they have priority."
        
        So with the automatic loading system for the mods, you should enable it with a 
        name like "zpdb", to assure that it is loaded at the end of the loading loop.
"""


"""
Available and enabled assets bundles for this project
"""
from django_assets import Bundle, register

AVALAIBLE_BUNDLES = {
    # Modernizr bundle, compatible for all Foundation releases
    'modernizr_js': Bundle(
        "js/foundation5/vendor/modernizr.js",
        filters='yui_js',
        output='js/modernizr.min.js'
    ),
    
    
    # Main CSS bundle For Foundation3
    'main_css': Bundle(
        'css/main.css',
        filters='yui_css',
        output='css/main.min.css'
    ),
    # Main Javascript bundle For Foundation3
    'main_js': Bundle(
        "js/foundation/jquery.js",
        #"js/foundation/jquery.foundation.forms.js",
        #"js/foundation/jquery.foundation.clearing.js",
        #"js/foundation/jquery.foundation.magellan.js",
        "js/foundation/jquery.foundation.orbit.js",
        #"js/foundation/jquery.foundation.navigation.js",
        #"js/foundation/jquery.foundation.accordion.js",
        "js/foundation/jquery.foundation.topbar.js",
        "js/foundation/jquery.cookie.js",
        #"js/foundation/jquery.foundation.joyride.js",
        #"js/foundation/jquery.foundation.tabs.js",
        "js/foundation/jquery.foundation.buttons.js",
        #"js/foundation/jquery.foundation.reveal.js",
        "js/foundation/jquery.event.swipe.js",
        #"js/foundation/jquery.foundation.alerts.js",
        "js/foundation/jquery.placeholder.js",
        #"js/foundation/jquery.foundation.tooltips.js",
        #"js/foundation/jquery.foundation.mediaQueryToggle.js",
        "js/foundation/jquery.event.move.js",
        "js/jquery/equalize.js",
        "js/jquery/addons.js",
        "js/foundation/app.js",
        filters='yui_js',
        output='js/main.min.js'
    ),
    
    
    # Main CSS bundle For Foundation5
    'app_css': Bundle(
        'css/flags.css',
        'css/app.css',
        filters='yui_css',
        output='css/app.min.css'
    ),
    # Main Javascript bundle For Foundation5
    'app_js': Bundle(
        "js/foundation5/vendor/jquery.js",
        #"js/foundation5/vendor/fastclick.js",
        #"js/foundation5/vendor/lodash.js", # This one is most used for Foundation development
        #"js/foundation5/vendor/jquery.placeholder.js", # This one is most used for Foundation development
        "js/foundation5/vendor/jquery.cookie.js",
        "js/foundation5/foundation/foundation.js",
        "js/foundation5/foundation/foundation.abide.js",
        "js/foundation5/foundation/foundation.accordion.js",
        "js/foundation5/foundation/foundation.alert.js",
        "js/foundation5/foundation/foundation.clearing.js",
        "js/foundation5/foundation/foundation.dropdown.js",
        #"js/foundation5/foundation/foundation.equalizer.js", # Foundation equalizer actually lacks of a responsive option like our addon
        "js/foundation5/foundation/foundation.interchange.js",
        "js/foundation5/foundation/foundation.joyride.js",
        "js/foundation5/foundation/foundation.magellan.js",
        "js/foundation5/foundation/foundation.offcanvas.js",
        "js/foundation5/foundation/foundation.reveal.js",
        "js/foundation5/foundation/foundation.slider.js",
        "js/foundation5/foundation/foundation.tab.js",
        "js/foundation5/foundation/foundation.tooltip.js",
        "js/foundation5/foundation/foundation.topbar.js",
        
        # For Orbit Slider (default used)
        "js/foundation5/foundation/foundation.orbit.js",
        
        ## For Royal Slider instead of Orbit (remember to enable its component in your 'app.scss')
        #"js/royalslider/dev/jquery.royalslider.js",
        #"js/royalslider/dev/modules/jquery.rs.video.js",
        #"js/royalslider/dev/modules/jquery.rs.thumbnails.js",
        #"js/royalslider/dev/modules/jquery.rs.auto-height.js",
        #"js/royalslider/dev/modules/jquery.rs.deeplinking.js",
        #"js/royalslider/dev/modules/jquery.rs.fullscreen.js",
        #"js/royalslider/dev/modules/jquery.rs.animated-blocks.js",
        #"js/royalslider/dev/modules/jquery.rs.autoplay.js",
        #"js/royalslider/dev/modules/jquery.rs.global-caption.js",
        #"js/royalslider/dev/modules/jquery.rs.visible-nearby.js",
        #"js/royalslider/dev/modules/jquery.rs.tabs.js",
        #"js/royalslider/dev/modules/jquery.rs.nav-auto-hide.js",
        #"js/royalslider/dev/modules/jquery.rs.autoplay.js",
        #"js/royalslider/dev/modules/jquery.rs.bullets.js",
        #"js/royalslider/dev/modules/jquery.rs.active-class.js",
        
        ## Magnific popup (modal window/pop-in)
        ##"js/jquery/magnific-popup.js",
        
        ## Masonry and socialaggregator libraries
        ##"js/masonry/masonry.pkgd.js",
        ##"js/socialaggregator.js",
        
        # Width/eight DOM element equalizer
        "js/jquery/equalize.js",
        
        ## Pikaday+moment.js for a datepicker
        #"js/moment.js",
        #"js/pikaday.js",
        #"js/jquery/pikaday.jquery.js",
        
        "js/jquery/addons.js",
        "js/app.js",
        filters='yui_js',
        output='js/app.min.js'
    ),
}
ENABLED_BUNDLES = [
    'modernizr_js',
    'main_css',
    'main_js',
    'app_css',
    'app_js',
]

for item in ENABLED_BUNDLES:
    register(item, AVALAIBLE_BUNDLES[item])



"""
Admins for contact forms
"""
from datetime import datetime
from django.contrib import admin
from django.conf.urls import patterns, url
from django.utils.translation import ugettext as _

# Import from django-excel-response
from excel_response import ExcelResponse

# Import from here
from models import ContactBase, Contact


class ContactBaseAdmin(admin.ModelAdmin):
    date_hierarchy = 'creation_date'
    list_display = ('first_name', 'last_name', 'email', 'phone', 'creation_date')
    list_filter = ('creation_date',)
    search_fields = ('first_name', 'last_name', 'email', 'phone', 'message')
    fieldsets = ((None, {'fields': ('civility', 'first_name', 'last_name',
                                    'email', 'phone', 'company')}),
                 (None, {'fields': ('message',)}),
        )
    actions_on_top = False
    actions_on_bottom = True

    def export(self, request):
        return ExcelResponse(
            ContactBase.objects.all(),
            'contact_form_%s' % datetime.now().strftime('%Y%m%d%H%M'))

    def get_urls(self):
        urls = super(ContactBaseAdmin, self).get_urls()
        my_urls = patterns(
            '',
            url(r'^export/$', self.admin_site.admin_view(self.export))
            )
        return my_urls + urls

class ContactAdmin(ContactBaseAdmin):
    list_display = ('first_name', 'last_name', 'company', 'city', 'country', 'creation_date')

    search_fields = ('first_name', 'last_name', 'company', 'email', 'phone', 'city', 'state')
    fieldsets = ((None, {'fields': ('first_name', 'last_name',
                                    'company')}),
                 (None, {'fields': ('message',)}),
                 (_('Contact'), {'fields': ('email', 'phone')}),
                 (_('Address'), {'fields': ('city', 'state', 'country')}),)

admin.site.register(Contact, ContactAdmin)



# -*- coding: utf-8 -*-
"""
Urls for contact forms
"""
from django.conf.urls import patterns, url
from django.views.generic.base import TemplateView
from .views import ContactFormView

urlpatterns = patterns('project.contact_form.views',
    url(r'^$', ContactFormView.as_view(), name='contact_form')
)

urlpatterns += patterns('django.views.generic.simple',
    url(r'^sent/$', TemplateView.as_view(template_name='contact_form/contact_form_sent.html'), name='contact_form_sent')
)



"""
Below is a list (non-exhaustive) of all the components available to create a new project.

Currently a new project installs the following (at least):

* `google_tools`_;
* `assets`_ to manage the assets;
* `cms`_ for `Django CMS`_;
* `codemirror`_ for the editor used in `Django CMS`_'s *snippet* plugin;
* `filebrowser`_ to manage the media uploaded in the CMS pages;
* `ckeditor`_ for the editor used with `Django CMS`_ and `Django Blog Zinnia`_;

If you do not want to use these components, you will need to manually disable them in your settings and the project's main ``urls.py``.

Also, there is a lot of mods that needs some private key, email adresses, services accounts, etc.. to be filled to works. Like 'contact_form' that needs to know a recipient email where it can send notifications. So after a first install remember to watch your mod settings to see if they need some datas to fill.
"""


# -*- coding: utf-8 -*-
"""
Here we bind Sitemap containers for each available apps and ressources

This default config is made to support DjangoCMS, Zinnia, Porticus and staticpages, 
only DjangoCMS is enabled, uncomment the others or add new app ressources for your 
needs (see the Django sitemap documentation for more details)
"""
from django.conf import settings
from django.core.urlresolvers import reverse

#from project.contact_form.sitemaps import ContactFormEntryBase, ContactFormSitemapBase

from cms.sitemaps import CMSSitemap

#from zinnia.sitemaps import TagSitemap
#from zinnia.sitemaps import EntrySitemap
#from zinnia.sitemaps import CategorySitemap
#from zinnia.sitemaps import AuthorSitemap

from staticpages.sitemaps import StaticPageSitemapAuto

#from porticus.models import Album
#from porticus.sitemaps import PorticusAlbumSitemap


#class BookingFormEntry(ContactFormEntryBase):
    #"""Booking form entry for Contact forms sitemap"""
    #url_name = 'booking_form'

#class ContactFormSitemap(ContactFormSitemapBase):
    #"""Contact forms sitemap"""
    #contact_forms = [BookingFormEntry]


#class PrototypesSitemap(StaticPageSitemapAuto):
    #"""Prototypes sitemap"""
    #pages_map = settings.STATICPAGES_PROTOTYPES


#class PorticusAlbumVisiteSitemap(PorticusAlbumSitemap):
    #"""
    #Custom Porticus album sitemap to only display the Album 'Visite'
    #"""
    #priority = 1.0
    
    #def items(self):
        #return Album.objects.filter(slug="visite").order_by('priority', 'name')
    
    #def location(self, obj):
        #return reverse('porticus-visite-album-detail')


# Enabled sitemaps
sitemaps = {
    ## For Porticus
    #'albums': PorticusAlbumVisiteSitemap,
    ## For Contact forms
    #'contact': ContactFormSitemap,
    # For DjangoCMS
    'cmspages': CMSSitemap,
    # For Zinnia
    ###'tags': TagSitemap,
    #'blog': EntrySitemap,
    ###'authors': AuthorSitemap,
    #'categories': CategorySitemap,
    
    ## For Prototypes 
    ## WARNING: This should not be enabled in production
    #'prototypes': PrototypesSitemap,
}


# Full sitemap
urlpatterns += patterns('django.contrib.sitemaps.views',
    url(r'^sitemap\.xml$', 'sitemap', {'sitemaps': sitemaps}),
) + urlpatterns

## Sitemap divised into an index + sections
#urlpatterns += patterns('django.contrib.sitemaps.views',
    #url(r'^sitemap.xml$', 'index', {'sitemaps': sitemaps}),
    #url(r'^sitemap-(?P<section>.+)\.xml$', 'sitemap', {'sitemaps': sitemaps}),
#) + urlpatterns



"""
Enable the `Django reCaptcha`_ module to integrate a field of the *captcha* type via the `Service reCaptcha`_. This integration uses a special template and CSS to make it *responsive*.

If you do in fact use this module, go to its mods setting file (or that of your environment) to fill in the public key and the private key to be used to transmit the data required.

By default, these keys are filled in with a *fake* value and the captcha's form field therefore sends back a silent error (a message is inserted into the form without creating a Python *Exception*).
"""


"""
Enable the use of `django-crispy-forms`_ and `crispy-forms-foundation`_. **crispy_forms** is used to manage the HTML rendering of the forms in a finer and easier fashion than with the simple Django form API. **crispy-forms-foundation** is a supplement to implement the rendering with the structure (tags, styles, etc.) used in `Foundation`_.
"""


from django.conf import settings
from django.conf.urls import include, patterns, url

if settings.DEBUG:
    import debug_toolbar
    urlpatterns += patterns('',
        url(r'^__debug__/', include(debug_toolbar.urls)),
    )


"""
Settings for emencia-django-socialaggregator (EDSA)
"""
INSTALLED_APPS = add_to_tuple(INSTALLED_APPS,
    'django_extensions',
    'taggit',
    'socialaggregator')

# Optional specific formatter
#RESSOURCE_FORMATTER = "project.mods_available.socialaggregator.formatter.RessourceFormatterCustom"

# Twitter access keys
EDSA_TWITTER_TOKEN = 'FILLME'
EDSA_TWITTER_SECRET = 'FILLME'
EDSA_TWITTER_CONSUMER_KEY = 'FILLME'
EDSA_TWITTER_CONSUMER_SECRET = 'FILLME'

# Instagram access keys
EDSA_INSTAGRAM_ACCESS_TOKEN = 'FILLME'

# Facebook access keys
EDSA_FB_APP_ID = 'FILLME'
EDSA_FB_APP_SECRET = 'FILLME'
# Google+ access keys
EDSA_GOOGLE_DEVELOPER_KEY = 'FILLME'

# Pagination for ressource list in views
EDSA_PAGINATION = 16

# Enabled plugins and their engine
EDSA_PLUGINS = {
    "edsa_twitter": {
        #"ENGINE": "socialaggregator.plugins.twitter_aggregator",
        "ENGINE": "socialaggregator.plugins.twitter_noretweet_aggregator",
        "NAME": "Twitter"
    },
    "edsa_instagram": {
        "ENGINE": "socialaggregator.plugins.instagram_aggregator",
        "NAME": "Instagram"
    },
    "edsa_facebook_fanpage": {
        "ENGINE": "socialaggregator.plugins.facebook_fanpage_aggregator",
        "NAME": "Facebook Fanpage"
    },
    "edsa_wordpress_rss": {
        "ENGINE": "socialaggregator.plugins.wordpress_rss_aggregator",
        "NAME": "Wordpress RSS"
    },
    "edsa_youtube_search": {
        "ENGINE": "socialaggregator.plugins.youtube_search_aggregator",
        "NAME": "Youtube search"
    },
}

# Used templates
EDSA_VIEW_TEMPLATE = 'socialaggregator/ressource_list.html'
EDSA_TAG_TEMPLATE = 'socialaggregator/ressource_list_tag.html'
EDSA_PLUGIN_TEMPLATE = 'socialaggregator/cms_plugin_feed.html'

# Image size limit (in Ko, use 0 for no size limit)
EDSA_RESSOURCE_IMAGE_SIZE = 0

# Various ressource fields choices
EDSA_RESSOURCE_VIEW_SIZES = (
    ('default', gettext('default')),
    ('small', gettext('small')),
    #('xsmall', gettext('Xsmall')),
    ('medium', gettext('medium')),
    ('large', gettext('large')),
    #('xlarge', gettext('Xlarge')),
)

EDSA_RESSOURCE_TEXT_DISPLAY = (
    ('default', gettext('default')),
    #('bottom', gettext('bottom')),
    #('top', gettext('top')),
)

EDSA_RESSOURCE_BUTTON_COLOR = (
    ('white', gettext('white')),
    #('black', gettext('black')),
    #('primary', gettext('primary')),
    #('secondary', gettext('secondary')),
    #('tertiary', gettext('tertiary')),
)

EDSA_RESSOURCE_MEDIA_TYPE = (
    ('url', gettext('url')),
    ('image', gettext('image')),
    ('video', gettext('video')),
)

# Media content types to add to the ones from EDSA_PLUGINS
EDSA_RESSOURCE_BASE_MEDIA_TYPES = [
    ('edsa_article', 'Article Event'),
]


# -*- coding: utf-8 -*-
INSTALLED_APPS = add_to_tuple(INSTALLED_APPS, 'staticpages')

STATICPAGES_PROTOTYPES = (
    (r'prototypes/$', "prototypes/index.html", 'prototypes-index'),
    (r'prototypes/buttons/$', "prototypes/buttons.html", 'prototypes-buttons'),
)



"""
Enable the `emencia-django-slideshows`_ app to manage slide animations (slider, carousel, etc.). This was initially provided for `Foundation Orbit` and *Royal Slider*, but can be used with other libraries if needed.
"""


# -*- coding: utf-8 -*-
"""
Dashboard stuff for admin_tools
"""
from django.core.urlresolvers import reverse
from django.utils.translation import ugettext_lazy as _

from admin_tools.dashboard import modules, Dashboard, AppIndexDashboard
from admin_tools.utils import get_admin_site_name

class CustomIndexDashboard(Dashboard):
    """
    Custom index dashboard for project.
    """
    def init_with_context(self, context):
        site_name = get_admin_site_name(context)
        # append a link list module for "quick links"
        self.children.append(modules.LinkList(
            _('Quick links'),
            layout='inline',
            draggable=False,
            deletable=False,
            collapsible=False,
            children=[
                [_('Return to site'), '/'],
                [_('Change password'),
                 reverse('%s:password_change' % site_name)],
                [_('Log out'), reverse('%s:logout' % site_name)],
            ]
        ))

        # append an app list module for "Applications"
        self.children.append(modules.AppList(
            _('Applications'),
            exclude=('django.contrib.*',),
        ))

        # append an app list module for "Administration"
        self.children.append(modules.AppList(
            _('Administration'),
            models=('django.contrib.*',),
        ))

        # append a recent actions module
        self.children.append(modules.RecentActions(_('Recent Actions'), 5))

        ## append a feed module
        #self.children.append(modules.Feed(
            #_('Latest Django News'),
            #feed_url='http://www.djangoproject.com/rss/weblog/',
            #limit=5
        #))

        ## append another link list module for "support".
        #self.children.append(modules.LinkList(
            #_('Support'),
            #children=[
                #{
                    #'title': _('Django documentation'),
                    #'url': 'http://docs.djangoproject.com/',
                    #'external': True,
                #},
                #{
                    #'title': _('Django "django-users" mailing list'),
                    #'url': 'http://groups.google.com/group/django-users',
                    #'external': True,
                #},
                #{
                    #'title': _('Django irc channel'),
                    #'url': 'irc://irc.freenode.net/django',
                    #'external': True,
                #},
            #]
        #))


class CustomAppIndexDashboard(AppIndexDashboard):
    """
    Custom app index dashboard for project.
    """

    # we disable title because its redundant with the model list module
    title = ''

    def __init__(self, *args, **kwargs):
        AppIndexDashboard.__init__(self, *args, **kwargs)

        # append a model list module and a recent actions module
        self.children += [
            modules.ModelList(self.app_title, self.models),
            modules.RecentActions(
                _('Recent Actions'),
                include_list=self.get_app_content_types(),
                limit=5
            )
        ]

    def init_with_context(self, context):
        """
        Use this method if you need to access the request context.
        """
        return super(CustomAppIndexDashboard, self).init_with_context(context)
